==> Nilm-0.7.3.tar.gz: Nilm-0.7.3/tests/readers/test_ethstream_capture.py <==
import os
import asyncio
import unittest
import asynctest
from unittest import mock
import numpy as np

from nilm.readers import ethstreamcapture
from joule import LocalPipe


ETHSTREAM_DUMP = os.path.join(os.path.dirname(
    __file__), 'capture_dumps', 'ethstream_data.bin')


class TestEthstreamCaptureCmd(unittest.TestCase):

    def setUp(self):
        with open(ETHSTREAM_DUMP, "rb") as f:
            self.ethstream_data = f.read()

    def test_starts_ethstream(self):

        mock_proc = mock.Mock()

        mock_proc.stdout.readexactly = asynctest.CoroutineMock(
            return_value=self.ethstream_data)
        # override default to match capture file
        ethstreamcapture.BLOCK_SIZE = 12000
        ec = ethstreamcapture.EthstreamCapture("192.168.1.209")
        ec._start_meter = asynctest.CoroutineMock(return_value=mock_proc)
        npipe_output = LocalPipe(layout="uint16_6", name="raw")

        async def output_func(data):
            # check data output
            ec.stop()

        loop = asyncio.get_event_loop()
        loop.run_until_complete(ec.run(npipe_output,
                                       align=True,
                                       nrows=1000))

        # check the data
        result = npipe_output.read_nowait(flatten=True)
        expected_data = np.frombuffer(self.ethstream_data, dtype="uint16")
        expected_data.shape = (1000, 6)
        np.testing.assert_array_equal(result[:, 1:], expected_data)

        # make sure ethstream subprocess is stopped
        mock_proc.terminate.assert_called_once_with()

==> Nilm-0.9.1.tar.gz: Nilm-0.9.1/tests/readers/test_ethstream_capture.py <==
import os
import asyncio
import unittest
import asynctest
from unittest import mock
import numpy as np

from nilm.readers import ethstreamcapture
from joule import LocalPipe

ETHSTREAM_DUMP = os.path.join(os.path.dirname(
    __file__), 'capture_dumps', 'ethstream_data.bin')


class TestEthstreamCaptureCmd(unittest.TestCase):

    def setUp(self):
        with open(ETHSTREAM_DUMP, "rb") as f:
            self.ethstream_data = f.read()

    def test_starts_ethstream(self):
        mock_proc = mock.Mock()

        mock_proc.stdout.readexactly = asynctest.CoroutineMock(
            return_value=self.ethstream_data)
        # override default to match capture file
        ethstreamcapture.BLOCK_SIZE = 12000
        ec = ethstreamcapture.EthstreamCapture("192.168.1.209")
        ec._start_meter = asynctest.CoroutineMock(return_value=mock_proc)
        npipe_output = LocalPipe(layout="uint16_6", name="raw")

        async def output_func(data):
            # check data output
            ec.stop()

        # loop = asyncio.get_event_loop()
        # loop.set_debug(True)
        asyncio.run(ec.run(npipe_output,
                           align=True,
                           nrows=1000))

        # check the data
        result = npipe_output.read_nowait(flatten=True)
        expected_data = np.frombuffer(self.ethstream_data, dtype="uint16")
        expected_data.shape = (1000, 6)
        np.testing.assert_array_equal(result[:, 1:], expected_data)

        # make sure ethstream subprocess is stopped
        mock_proc.terminate.assert_called_once_with()
